==> fast_app-2.0.0.tar.gz: lib/ui/alert/fast_alert.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

fastToast(BuildContext context, String msg, {duration = 1}) {
//  return Toast.show(
//    msg,
//    context,
//    duration: duration,
//    gravity: 3,
//    backgroundRadius: 10.0,
//    backgroundColor: Color.fromRGBO(0, 0, 0, 0.7),
//  );
  Fluttertoast.showToast(
      msg: msg,
      toastLength: Toast.LENGTH_SHORT,
      gravity: ToastGravity.CENTER,
      timeInSecForIosWeb: 1,
      backgroundColor: Colors.black.withAlpha(200),
      textColor: Colors.white,
      fontSize: 16.0
  );
}

fastToastSuccess(BuildContext context, String msg, {Function? timeOutCall}) {
  //创建一个OverlayEntry对象
  OverlayEntry overlayEntry = new OverlayEntry(builder: (context) {
    //外层使用Positioned进行定位，控制在Overlay中的位置
    return new Positioned(
        top: MediaQuery
            .of(context)
            .size
            .height * 0.5,
        child: new Material(
          color: Colors.transparent,
          child: new Container(
            color: Colors.transparent,
            width: MediaQuery
                .of(context)
                .size
                .width,
            alignment: Alignment.center,
            child: new Center(
              child: new Material(
                type: MaterialType.transparency,
                textStyle: new TextStyle(color: Colors.black),
                child: new Container(
                  decoration: BoxDecoration(
                    borderRadius:
                    new BorderRadius.all(new Radius.circular(12.0)),
                    color: Color.fromRGBO(0, 0, 0, 0.7),
                  ),
                  padding: EdgeInsets.symmetric(vertical: 10, horizontal: 10),
                  width: 120,
                  child: new Wrap(
                    crossAxisAlignment: WrapCrossAlignment.center,
                    children: <Widget>[
                      new Container(
                        width: double.infinity,
                        alignment: Alignment.center,
                        child: new Image.asset(
                          'assets/ic_confirm.webp',
                          width: 58,
                          height: 52,
                          package: "fast_app",
                        ),
                      ),
                      new Padding(
                        padding: EdgeInsets.only(top: 15),
                        child: new Center(
                          child: new Text(msg,
                            textAlign: TextAlign.center,
                            style: TextStyle(color: Colors.white),
                            maxLines: 5,
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        ));
  });
  //往Overlay中插入插入OverlayEntry
  Overlay.of(context)?.insert(overlayEntry);
  //两秒后，移除Toast
  new Future.delayed(Duration(seconds: 1)).then((value) {
    overlayEntry.remove();

    if (timeOutCall != null) {
      timeOutCall();
    }
  });
}

==> fast_app-2.1.1.tar.gz: lib/ui/alert/fast_alert.dart <==
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

fastToast(BuildContext context, String msg, {duration = 1}) {
//  return Toast.show(
//    msg,
//    context,
//    duration: duration,
//    gravity: 3,
//    backgroundRadius: 10.0,
//    backgroundColor: Color.fromRGBO(0, 0, 0, 0.7),
//  );
  Fluttertoast.showToast(
      msg: msg,
      toastLength: Toast.LENGTH_SHORT,
      gravity: ToastGravity.CENTER,
      timeInSecForIosWeb: 1,
      backgroundColor: Colors.black.withAlpha(200),
      textColor: Colors.white,
      fontSize: 16.0
  );
}

fastToastSuccess(BuildContext context, String msg, {Function? timeOutCall}) {
  //创建一个OverlayEntry对象
  OverlayEntry overlayEntry = new OverlayEntry(builder: (context) {
    //外层使用Positioned进行定位，控制在Overlay中的位置
    return new Positioned(
        top: MediaQuery
            .of(context)
            .size
            .height * 0.5,
        child: new Material(
          color: Colors.transparent,
          child: new Container(
            color: Colors.transparent,
            width: MediaQuery
                .of(context)
                .size
                .width,
            alignment: Alignment.center,
            child: new Center(
              child: new Material(
                type: MaterialType.transparency,
                textStyle: new TextStyle(color: Colors.black),
                child: new Container(
                  decoration: BoxDecoration(
                    borderRadius:
                    new BorderRadius.all(new Radius.circular(12.0)),
                    color: Color.fromRGBO(0, 0, 0, 0.7),
                  ),
                  padding: EdgeInsets.symmetric(vertical: 10, horizontal: 10),
                  width: 120,
                  child: new Wrap(
                    crossAxisAlignment: WrapCrossAlignment.center,
                    children: <Widget>[
                      new Container(
                        width: double.infinity,
                        alignment: Alignment.center,
                        child: new Image.asset(
                          'assets/ic_confirm.webp',
                          width: 58,
                          height: 52,
                          package: "fast_app",
                        ),
                      ),
                      new Padding(
                        padding: EdgeInsets.only(top: 15),
                        child: new Center(
                          child: new Text(msg,
                            textAlign: TextAlign.center,
                            style: TextStyle(color: Colors.white),
                            maxLines: 5,
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        ));
  });
  //往Overlay中插入插入OverlayEntry
  Overlay.of(context).insert(overlayEntry);
  //两秒后，移除Toast
  new Future.delayed(Duration(seconds: 1)).then((value) {
    overlayEntry.remove();

    if (timeOutCall != null) {
      timeOutCall();
    }
  });
}
